@@ -1,11 +1,18 @@
 import pytest
 
+from datetime import datetime
+
+from dateutil.tz import tzutc
+from dateutil.parser import parse as dtparse
+
 from ..packet import (Packet, RequestAccountCreate, Packet, PacketInvalidData,
                       NotifyAccountCreate, NotifyPersonDuplicate,
                       NotifyUserModify, RequestUserModify)
 from .fixtures import DEMO_JSON_PKT_1, DEMO_JSON_PKT_2
 
 
+
+
 class TestClient:
     """
     Test packet creation and processing.
@@ -200,6 +207,8 @@ class TestClient:
         packet_1 = Packet.from_dict(DEMO_JSON_PKT_1)
         packet_2 = Packet.from_dict(DEMO_JSON_PKT_2)
 
+        DATETIME_HEADER_FIELDS = ['packet_timestamp']
+
         # Check that the _original_data field matches
         assert packet_1._original_data == DEMO_JSON_PKT_1
         assert packet_2._original_data == DEMO_JSON_PKT_2
@@ -210,7 +219,10 @@ class TestClient:
                 # skip header fields we handle elsewhere
                 if k in ['expected_reply_list']:
                     continue
-                assert getattr(pkt, k) == v
+                elif k in DATETIME_HEADER_FIELDS:
+                    assert getattr(pkt, k) == dtparse(v)
+                else:
+                    assert getattr(pkt, k) == v
             for k, v in pkt._original_data['body'].items():
                 try:
                     pkt_v = getattr(pkt, k)
@@ -230,3 +242,10 @@ class TestClient:
 
         with pytest.raises(PacketInvalidData):
             rac_packet.validate_data(raise_on_invalid=True)
+
+    def test_packet_timestamp(self):
+        # Get a packet
+        packet = Packet.from_dict(DEMO_JSON_PKT_2)
+        # Test the timestamp is parsed correctly
+        timestamp = datetime(2021, 8, 24, 14, 47, 51, 507000, tzinfo=tzutc())
+        assert getattr(packet, 'packet_timestamp') == timestamp
